============
 txeasymail
============

`txeasymail`_ is a nicer SMTP client for `Twisted`_.

.. _`txeasymail`: https://github.com/lvh/txeasymail
.. _`Twisted`: https://www.twistedmatrix.com

.. image:: https://dl.dropbox.com/u/38476311/Logos/txeasymail.png
    :align: center
